class Mutable(object):
    '''
    Wrapper class to turn any immutable object mutable.
    '''
    # Add mutable operators
    import operator
    ops = ('__iadd__', '__iand__', '__iconcat__', '__idiv__',
           '__ifloordiv__', '__ilshift__', '__imod__', '__imul__',
           '__ior__', '__ipow__', '__irepeat__', '__irshift__',
           '__isub__', '__itruediv__', '__ixor__')
    this = vars()
    def generate_i(op):
        def fake_operator(o1, o2):
            o1.__object = op(o1.__object, o2)
            return o1
        return fake_operator
    def generate_o(op):
        def fake_operator(o1, o2):
            return op(o1.__object, o2)
        return fake_operator
    for op in vars(operator).iteritems():
        if op[0] in ops:
            this[op[0]] = generate_i(op[1])
        elif op[0].startswith('__') and 'slice' not in op[0] and callable(op[1]):
            this[op[0]] = generate_o(op[1])
    # clean up self
    del operator
    del ops
    del this
    del op
    del generate_i
    del generate_o
    # define methods
    def __init__(self, o):
        super(Mutable, self).__init__()
        self.__object = o
    # override methods:
    def __delattr__(self, a):
        return delattr(self.__object, a)
    def __getattribute__(self, a):
        if a.startswith('_Mutable__'):
            return object.__getattribute__(self, a)
        if not a.startswith('_') and hasattr(Mutable, a):
            return object.__getattribute__(self, a)
        return getattr(self.__object, a)
    def __repr__(self):
        return 'Mutable(%r)'%(self.__object,)
    def __setattr__(self, a, v):
        if a.startswith('_Mutable__'):
            return object.__setattr__(self, a, v)
        return setattr(self.__object, a, v)
    def __str__(self):
        return str(self.__object)
    def __len__(self):
        return len(self.__object)
    def __delitem__(self, *args):
        t = type(self.__object)
        l = list(self.__object)
        l.__delitem__(*args)
        if issubclass(t, basestring):
            self.__object = t('').join(l)
        else:
            self.__object = t(l)
    def __setitem__(self, *args):
        t = type(self.__object)
        l = list(self.__object)
        l.__setitem__(*args)
        if issubclass(t, basestring):
            self.__object = t('').join(l)
        else:
            self.__object = t(l)
    def extend(self, a):
        self.__object += a


def bytearray(*args):
    '''
    An inefficient implementation of bytearray for Python 2.5.
    '''
    data = str(*args)
    mutable = Mutable(data)
    return mutable

